@@ -18,11 +18,13 @@ function(CH, model=list(p~1), data=NULL, ci = 0.95, ciType=c("normal", "MARK"),
 
   # Convert the covariate data frame into a list
   dataList <- stddata(data, nocc)
-  dataList$.Time <- scale(1:nocc)
+  dataList$.Time <- standardize(1:nocc)
+  dataList$.Time2 <- dataList$.Time^2
+  dataList$.Time3 <- dataList$.Time^3
   dataList$.time <- as.factor(1:nocc)
   ddf <- as.data.frame(dataList)
 
-  pModMat <- model.matrix(model$p, ddf)
+  pModMat <- modelMatrix(model$p, ddf)
   K <- ncol(pModMat)
 
   beta.mat <- matrix(NA_real_, K+1, 4) # objects to hold output
