@@ -70,22 +70,22 @@ occMScovSite <- function(DH, occsPerSeason,
   psi1df <- selectCovars(model$psi1, dataList, nSites)
   if (nrow(psi1df) != nSites)
     stop("Covariate for psi1 is wrong length.")
-  psi1Mat <- model.matrix(model$psi1, psi1df)
+  psi1Mat <- modelMatrix(model$psi1, psi1df)
   if (nrow(psi1Mat) != nSites)
     stop("Missing values not allowed in site covariates.")
   psi1K <- ncol(psi1Mat)
   gamDf <- selectCovars(model$gamma, dataList, nSites*(nseas-1))
-  gamMat <- model.matrix(model$gamma, gamDf)
+  gamMat <- modelMatrix(model$gamma, gamDf)
   if (nrow(gamMat) !=  nSites*(nseas-1))
     stop("Missing values not allowed in site covariates.")
   gamK <- ncol(gamMat)
   epsDf <- selectCovars(model$epsilon, dataList, nSites*(nseas-1))
-  epsMat <- model.matrix(model$epsilon, epsDf)
+  epsMat <- modelMatrix(model$epsilon, epsDf)
   if (nrow(epsMat) !=  nSites*(nseas-1))
     stop("Missing values not allowed in site covariates.")
   epsK <- ncol(epsMat)
   pDf <- selectCovars(model$p, dataList, nSites*nseas)
-  pMat <- model.matrix(model$p, pDf)
+  pMat <- modelMatrix(model$p, pDf)
   pK <- ncol(pMat)
   K <- psi1K + gamK + epsK + pK
   parID <- rep(1:4, c(psi1K, gamK, epsK, pK))
